@@ -27,6 +27,7 @@
 
 // Global includes
 #include <QtGui/QProgressDialog>
+#include <QtGui/QMessageBox>
 
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -122,6 +123,15 @@ void MessageWidgetPrivate::onChooseContactButtonClicked()
   // Let the user choose a number
   if ( get_contact_for_sms(&dialogTitle, &name, &number, &uid) )
   {
+    // Try to get the number in a international format
+    if ( !make_number_international(&number) )
+    {
+      QMessageBox::critical(self, tr("Wrong number format"),
+          tr("%1's phone number \"%2\" could not be converted to an international format.").arg(name).arg(number));
+
+      return; // There's no reason to continue
+    }
+
     // Get the current text
     QString currentText = ui.contactEdit->text();
 
